function  [s,vel,acc] = polynom_pl2(se,tb,tv,te,vm,am,dt)


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%poly1.m
%POLYNOM Berechnung des Polynomprofils
% 
% [s,vel,acc] = polynom_pl2(se,tb,tv,te,vm,am,dt)
%
%
% INPUT:	
%	se [se(1)	Strecke
%	    se(2)
%	     ...]
%	     
%	tb [tb(1)	Beschleunigungszeit
%	    tb(2)
%	     ...]
%	     
%	tv [tv(1)	Bremszeit
%	    tv(2)
%	     ...]
%	     
%	te [te(1)	Gesamtzeit der Bahn
%	    te(2)
%	     ...]
%	     	    	    		
%	vm [vm(1)	maximale Geschwindigkeit
%	    vm(2)
%	     ...]
%	    
%	am [am(1)	maximale Beschleunigung
%	    am(2)
%	     ...]
%	    	
%	dt		Interpolationszeit
%	
% OUTPUT:
%
%	s		Matrize der Streckennderungen	
% 	vel		Matrize der Geschwindigkeitsnderungen
% 	acc		Matrize der Beschleunigungsnderungen	
% 		
% globale Variablen:
%			keine
%		
% aufgerufene Funktionen:
%			keine
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Initialisierung
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

rows = size(se,1);

temax = max(te);
tast  = round(temax/dt);  		% Anzahl der Spalten

st   = zeros(rows,1);
s    = zeros(rows,tast);
at   = zeros(rows,1);
acc  = zeros(rows,tast);
vt   = zeros(rows,1);
vel  = zeros(rows,tast);
zero = zeros(rows,1);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Berechnung der Gelenkwinkel-, Geschwindigkeits- und Beschleunigungssollwerte
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
for h=1:1:tast,

  t = h * dt;

  i= find(  0 <=t  &  t <= tb);
  
    st (i) =(( ( (4*am(i))./tb(i) )  *t^3) /6) + (( ( (-4*am(i))./tb(i).^2) *t^4) /12);
    vt(i) = (.5*(4*am(i)./tb(i)).*t.^2)+(1/3*(-4*am(i)./(tb(i).^2)).*(t.^3));    
    at(i) = ((4*am(i)./tb(i))*t)+((-4*am(i)./(tb(i).^2))*t.^2);
  

  i= find( tb < t  &  t <= tv);
  
    st(i) = ( vm(i).*(t-tb(i)) ) + ( (0.75*vm(i).^2)./am(i) );
    vt(i) = vm(i);
    at(i) = zero(i);

  i= find( tv < t  &  t <= te);

    st(i) = ( ((4*am(i)./tb(i)) .* (t-tv(i)).^3 )/(-6) ) -  ((( -4*am(i)./tb(i).^2) .* (t-tv(i)).^4) / 12) +...
         ( vm(i) .*(t-tv(i))) + (vm(i).* (te(i)-2*tb(i)) ) + ((0.75*vm(i).^2)./am(i) );
    vt(i) = vm(i)-(.5*(4*am(i)./tb(i)).*(t-tv(i)).^2)-(1/3*(-4*am(i)./(tb(i).^2)).*(t-tv(i)).^3);
    at(i) = (-(4*am(i)./tb(i)).*(t-tv(i)))+((4*am(i)./(tb(i).^2)).*(t-tv(i)).^2);						;

  i= find( te < t );

    st(i) = se(i);
    vt(i) = zero(i);
    at(i) = zero(i);

  s(:,h)   = st;
  vel(:,h) = vt;  
  acc(:,h) = at;

end;

