function [sptp,status,qp_ptp,qpp_ptp] = ptp_pl2(qA,qCor,vm,am,SyncFlag,ipoart,dt)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%  ptp.m
%  PTP   Berechnung einer PTP-Bahn
%  [sptp,status,vel,acc] = ptp_pl2 (qA,qCor,vm,am,SyncFlag,ipoart,dt)
%
%
%  INPUT:
%
%	qA [qA(1)	Vektor der Anfangswerte
%	    qA(2)
%	     ...]
%	     
%   qCor [qCor(1)	Vektor der Zielwerte
%
%	  qCor(2)
%	     ...]
%	     	    	    		
%	vm [vm(1)	maximale Geschwindigkeit
%	    vm(2)
%	     ...]
%	    
%	am [am(1)	maximale Beschleunigung
%	    am(2)
%	     ...]
%
%     	 SyncFlag       0 (asynchrone PTP-Bahn)
%		        1 (synchrone PTP-Bahn)
%             2  vollsynchrone Bahn
%	  ipoart: 	1 (Rampe) 
%			2 (Sinoid)
%			3 (Polynom)
%	 	
%	dt		Interpolationszeit (Schrittweite)
%
%
%  OUPUT:
%	sptp		Gelenkwinkelmatrix ber die gefahrene Dauer
%	vel		Geschwindigkeitsprofil
%	acc		Beschleunigungsprofil
%	status		Fehlernummer
%
%
% 
%
% aufgerufene Funktionen:
%	[...] = rampe(...)
%	[...] = polynom_pl2 (...)
%	[...] = sinoid(...)
%	[...] = rtrafo_pl2  (...)
%	
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Vorberechnungen
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Initialisierungen
vel	= [];
  acc	= [];
  s=[];

status = 0;				% status initialisieren

if (qA == qCor),			% wenn Startlage = Ziellage
  sptp	= [qCor];
  vel	= [0;0];
  acc	= [0;0];
  return;
end;


Vorz = sign(qCor - qA);				% Diese Vorberechungen knnen vor die Profilerkennung gezogen werden,
se = abs(qCor - qA);				% da sie fr alle drei Profile gleich sind
rows = size(se,1);

i = find(se==0);				% i findet Stellen in der Bahnlnge, die nicht verndert werden
selim = ones(rows,1);
selim = 1e-6*selim;				% die Null wird mit 1e-6 korrigiert
se(i) = selim(i); 				% korrigierte Bahnlnge

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Abfrage auf Bahnprofil und Vorberechnungen
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


if(ipoart == 1),				% Bei ipoart = 1, werden die Vorberechnungen fr die Rampenbahn durchgefhrt
%%%%%%%%%%%%%%xxxxxxxxxx

%%%%%%%%%%%%%%%%%%%%%%%%%xxxxxxxxxxxxxxxxxxxx
  tb = vm./am;
  te = (se./vm) + tb;
  tv = te - tb;

  i = find(te < 2*tb);				% * findet die Indizes der Achsen, fr die Vmax nicht erreicht werden kann
    status=9;
    vm(i)= real((se(i).*am(i)).^0.5); 		% * real() nur zur absoluten Sicherheit, da keine Imaginrteile auftreten
    tb(i)= vm(i)./am(i);
    te(i)= 2 *tb(i);
    tv(i)= tb(i);
    
end;
    

if (ipoart == 2),				% Bei ipoart = 2, werden die Vorberechnungen fr die Sinoidenbahn durchgefhrt		

tb = (2*vm)./am;
      te = tb + (se./vm);
      tv = te - tb;
i = find (vm > real(sqrt(.5*se.*am)));
	
      vm(i) = real(sqrt(.5*se(i).*am(i)));
      tb(i) =(2*vm(i)./am(i));
      te(i) = sqrt(8*se(i)./am(i));
      tv(i) = tb(i);
    

end;
  
if (ipoart == 3),				% Bei ipoart = 3, werden die Vorberechnungen fr die Polynombahn durchgefhrt

  tb = ((3*vm)./(2*am));
  te = (se./vm)+tb;
  tv = te - tb;

  i = find(te<2*tb);				%* Korrektur, falls vmax nicht erreicht wird
    vm(i) = real(sqrt((2/3)*(se(i).*am(i))));
    tb(i) = ((3*vm(i))./(2*am(i)));
    te(i) = 2*tb(i);
    tv(i) = tb(i);
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Synchroner und vollsynchroner Bahnverlauf
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if (ipoart == 1 & SyncFlag == 1)   % hier: synchrone Rampenbahn

      temax = max(te);
      te    = temax*ones(rows,1);
      k     = am*(temax /2);
      vm    = real(k -( (k.^2) -se.*am ).^0.5);  	% * Imaginrteile unterdrcken
      tb    = vm./am;
      tv    = te - tb;
      
end;

if (ipoart == 1 & SyncFlag == 2)   % hier: vollsynchrone Rampenbahn

      [temax,index] = max(te);  % index: Ordnungsnummer des Gelenkes mit temaxe 
      te    = temax*ones(rows,1); % wieder Vektor
      tbmax=tb(index); % entsprechendes tb
      tb    = tbmax*ones(rows,1); % alle tb gleich
      tv=te-tb;
      vm    = se ./ tv;  	% * Imaginrteile unterdrcken
      am    = vm./tb;
end;

if (ipoart == 2 & SyncFlag == 1),    % hier: synchrone Sinoidenbahn
  temax = max(te);
  te    = temax*ones(rows,1);
  vm    = (.25*(te.*am))-real(sqrt((te.*am).^2/16 -(.5*(se.*am)))); 	% * Imaginrteile unterdrcken
  tb    = (2*vm)./am;
  tv    = te - tb;
end;

if (ipoart == 2 & SyncFlag == 2)   % hier: vollsynchrone sinoidenbahn

      [temax,index] = max(te);  % index: Ordnungsnummer des Gelenkes mit temax 
      te    = temax*ones(rows,1); % wieder Vektor
      tbmax=tb(index); % entsprechendes tb
      tb    = tbmax*ones(rows,1); % alle tb gleich
      tv=te-tb;
      vm    = se ./ tv;  
      am    = 2*vm./tb;
end;

if (ipoart == 3 & SyncFlag == 1),    % hier: synchrone Polynombahn
 temax = max(te);
 te = temax*ones(rows,1);
 vm = ((temax*(2*am))/6)-real(sqrt(((temax^2*(4*am.^2))/36)-((se.*(2*am))/3)));
 tb = ((3*vm)./(2*am));
 tv  = te - tb;
end;

if (ipoart == 3 & SyncFlag == 2)   % hier: vollsynchrone Polynombahn
   [temax,index] = max(te);  % index: Ordnungsnummer des Gelenkes mit temaxe 
      te    = temax*ones(rows,1); % wieder Vektor
      tbmax=tb(index); % entsprechendes tb
      tb    = tbmax*ones(rows,1); % alle tb gleich
      tv=te-tb;
      vm    = se ./ tv;  
      am    = 1.5*vm./tb;
end;

clear SyncFlag;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Berechnung der Bahn, Geschwindigkeit und Beschleunigung
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if (ipoart == 1),
  [s,vel,acc] = rampe(se,tb,tv,te,vm,am,dt);
end;


if (ipoart == 2),
  [s,vel,acc] = sinoid(se,tb,tv,te,vm,am,dt);
end;


if (ipoart == 3),
  [s,vel, acc] = polynom_pl2(se,tb,tv,te,vm,am,dt);
 end;

m = size(s,2);						% m holt sich die Anzahl der Abtastpunkte aus der Matrix
sptp = zeros(2:1);					% Vordimensionierung der Bahnmatrix
qp_ptp = zeros(2:1);					% Vordimensionierung der Bahnmatrix
qpp_ptp = zeros(2:1);					% Vordimensionierung der Bahnmatrix
  
   
  for b=1:1:(m-1),
    
    q_dh = s(1:2,b).*Vorz+qA;				% Anfgen des Vorzeichen und des Startpunktes an die Bahn
    qpp_dh=acc(1:2,b).*Vorz;
    qp_dh=vel(1:2,b).*Vorz;
    
    qpp_ptp=[qpp_ptp qpp_dh];
    qp_ptp=[qp_ptp qp_dh];

    sptp = [sptp q_dh];  
    
  end
    
  %sptp = [sptp qCor];    % sichern, dass letzter Wert Zielwert ist (fr Programme bei denen .
    sptp = [qA sptp qCor];    % sichern, dass letzter Wert Zielwert ist (fr Programme bei denen .

    qpp_ptp=[[0;0] qpp_ptp [0;0]];
    qp_ptp=[[0;0] qp_ptp [0;0]];

  