function [q,error_msg] = rtrafo_pl2(p_vek,Loeswahl,l1,l2)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%   RTRAFO fr Zweigelenkroboter planar
%   W. Weber: 20.06.01
%
%   Eingabe: pvek: Ortsvektor des TCP in K0 mit den Komponenten x0, y0
%   Loeswahl:  1 oder -1 , wird benutzt, um zwischen zwei Lsungen auszuwhlen.
%              bei +1 wird die 
%   Ausgabe: q Vektor mit den Komponenten q(1), q(2): D.-H. Winkel der Gelenke 1 und 2
%            error_msg: String Variable mit Fehlermeldung, Mglichkeiten:
%            error_msg=[] :  kein Fehler
%            error_msg=['TCP auf dem Rand des Arbeitsbereiches                       '
%                       'Vorzeichen der Orientierung kann nicht bercksichtigt werden']
%            error_msg=['Lsung nicht mglich: TCP ausserhalb des Arbeitsbereiches: Ende'] 
%
%   globale Variablen: l1,l2 : Lnge der Armteile
%
%   Die Rckwrtstransformation basiert auf folgenden D.-H-Parametern
%   d1=0, d2=0, a1=l1, a2=l2, alpha1=0, alpha2=0;

%   W. Weber, 2000
%   letzte nderung 4.8.2007
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%global l1 l2

hxx=l1+l2;

px=p_vek(1);
py=p_vek(2);


% Berechnung des Betrags von p
betrag_p=sqrt(px^2+py^2);

% berechnung von alfa
alfa=atan2(py,px);

if betrag_p <= (l1+l2)
   
	if betrag_p == (l1+l2)
      error_msg=['TCP auf dem Rand des Arbeitsbereiches                       '
                 'Vorzeichen der Orientierung kann nicht bercksichtigt werden']
      q1=alfa;
      q2=0;
      
   else
     
	error_msg=[];
	% berechnung von beta
	zw1=(l1^2+betrag_p^2-l2^2)/(2*l1*betrag_p);
	beta=acos(zw1);

	% Berechnung von gamma 
	gamma=acos((l1^2-betrag_p^2+l2^2)/(2*l1*l2));

%	 Festlegung der Lsungen
		if Loeswahl == 1 
   		q1=alfa-beta;
   		q2=pi-gamma;
   
		else
   		q1=alfa+beta;
   		q2=pi+gamma;
   		if q2 < -pi;
      		q2=q2+2*pi;
   		end
   		if q2 > pi
      		q2=q2-2*pi;
   		end
   
		end
	end

q=[q1;q2];


else
   error_msg=['Lsung nicht mglich: TCP ausserhalb des Arbeitsbereiches: Ende']
   q=[];
end


   

