%%%%% Kubische splines, hier im Beispiel dreier programmierter Winkel, qa, qb, qc, 
%%%%% d.h. zweier Bahnsegmente wobei 
%%%%% qb mit einer definierten Geschwindigkeit zu durchfahren ist
%%%%% 10.9.01, W. Weber
%%%%%  Letzte nderung: Februar 2002 von W. Weber
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
close all; % Alle Grafikfenster zu

str_ueb=['----------------------------------------------------------------------'
   ' PTP-Spline Interpolation bei einer Sttzstelle                       '
   '   W. Weber, Februar 2002                                             '
   '----------------------------------------------------------------------'
   '                                                                      '] ;
disp(str_ueb);



% Eingabe der Spline-Parameter
qa=input('Gelenkkoordinate am Start in rad oder m: ');
qb=input('Gelenkkoordinate Zwischenstellung in rad oder m: ');
qc=input('Gelenkkoordinate am Ziel in rad oder m: ');

v01=input('Betrag der Geschwindigkeit am Start in rad/sec oder m/sec: ')
ve1=input('Betrag der Geschwindigkeit beim Durchfahren des Zwischenpunktes in rad/sec oder m/sec: ')
ve2=input('Betrag der Geschwindigkeit am Ziel in rad/sec oder m/sec: ')

te1=input('Fahrzeit Bahnsegment 1 in Sek.: ')
te2=input('Fahrzeit Bahnsegment 2 in Sek.: ')


se1=qb-qa;
vorz1=sign(se1);
ve1=sign(qb-qa)*abs(ve1)

se2=qc-qb;
vorz2=sign(se2);
v02=ve1; % Mit gleicher Geschwindigkeit durchfahren



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%  Bahnberechnung
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
a2=[ 0 0];

te=[te1 te2];
v0=[v01 v02];
ve=[ve1 ve2];
se=[se1 se2];

t_vek_1=[0:0.01:te(1)];
t_vek_2=[0:0.01:te(2)];

a2(1)=3*se(1)/te(1)^2-(ve(1)+2*v0(1))/te(1);
a3(1)=-2*se(1)/te(1)^3+(ve(1)+v0(1))/te(1)^2;

a2(2)=3*se(2)/te(2)^2-(ve(2)+2*v0(2))/te(2);
a3(2)=-2*se(2)/te(2)^3+(ve(2)+v0(2))/te(2)^2;

s1=qa+v0(1)*t_vek_1 + a2(1) * t_vek_1.* t_vek_1 + a3(1) *  t_vek_1 .* t_vek_1 .* t_vek_1;
sp1=v0(1) + 2*a2(1)*t_vek_1 + 3*a3(1)*t_vek_1 .* t_vek_1; 
spp1=2*a2(1)+6*a3(1)*t_vek_1;

s2=qb+v0(2)*t_vek_2 + a2(2) * t_vek_2 .* t_vek_2 + a3(2) *  t_vek_2 .* t_vek_2 .* t_vek_2;
sp2=v0(2) + 2*a2(2)*t_vek_2 + 3*a3(2)*t_vek_2 .* t_vek_2; 
spp2=2*a2(2)+6*a3(2)*t_vek_2;


% absolute Winkel
% t_vek_abs=[0:0.01:(te(1)+te(2))];
t_vek_abs=[0:0.01:te(1), te(1):0.01:(te(1)+te(2))];


q=[s1,s2];
qp=[sp1,sp2];
qpp=[spp1,spp2];

% Vergleich mit Matlab spline, entspricht eigenen Berechnungen
%
%x_feld=[0, te]
%y_feld=[v0,0,2*se,ve]
%s_mat=spline(x_feld,y_feld,t_vek);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Berechnung fr zwei Rampenbahnen mit gleichem te1, te2 zum Vergleich
% Bahnparameter fr Rampenbahn zum Vergleich:
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
bm1=input('Beschleunigung fr Rampenbahn im ersten Bahnsegment in rad/sec(zum Vergleich): ');
	se1=abs(qb-qa);
   bm1=max(bm1,4*se1/te1^2);
   vm1=(bm1*te1/2)-sqrt(bm1^2*te1^2/4 - se1*bm1); 
   tb1=vm1/bm1;
   tv1=te1-tb1;
bm2=input('Beschleunigung fr Rampenbahn im zweiten Bahnsegment in rad/sec (zum Vergleich): ');
	se2=abs(qc-qb);
	bm2=max(bm2,4*se2/te2^2);
   vm2=(bm2*te2/2)-sqrt(bm2^2*te2^2/4 - se2*bm2); 
   tb2=vm2/bm2;
   tv2=te2-tb2;


close all;
sptp1=[]; vel1=[]; acc1=[];
sptp2=[]; vel2=[]; acc2=[];

T_Ipo=0.01;

[sptp1,vel1,acc1] = rampe_te(abs(se1),tb1,tv1,te1,vm1,bm1,T_Ipo); % Rampenbahn zum Vergleich

  
[sptp2,vel2,acc2] = rampe_te(abs(se2),tb2,tv2,te2,vm2,bm2,T_Ipo); % Rampenbahn zum Vergleich


q_rampe=[qa+vorz1*sptp1, qb+vorz2*sptp2];
qp_rampe=[vorz1*vel1, vorz2*vel2];
qpp_rampe=[vorz1*acc1, vorz2*acc2];
t_ptp=[0:0.01:(te1+te2)];
t_ptp=[0:0.01:te1, fix(te1/0.01)*0.01:0.01:(te1+te2)];

% Vorgabe von Text
	text_x_1= 'Zeitin Sekunden';
  	text_w='Gelenkoordinate q';
  	text_wp='dq/dt';
  	text_wp_rampe='dq/dt fr Rampenbahnen';
	text_wpp='dq/dt';




figure

subplot(2,2,1)
q_pl=plot(t_vek_abs,q,'r');
title('PTP-Spline 3. Ordnung, gestr. PTP-Vergl. Bahn');
grid on;
xlabel(text_x_1);
ylabel(text_w);
hold on;
plot(t_ptp,q_rampe,'k--');

subplot(2,2,2);
qp_pl=plot(t_vek_abs,qp,'r');
%title('PTP-Spline 3. Ordnung, Gelenkgeschwindigkeit')
grid on;
hold on;
plot(t_ptp,qp_rampe,'k--');
xlabel(text_x_1);
ylabel(text_wp);


subplot(2,2,3);
plot(t_vek_abs,qpp,'r');
hold on
plot(t_ptp,qpp_rampe,'k--');
%title('PTP-Spline 3. Ordnung, Gelenkbeschleunigung')
grid on;
xlabel(text_x_1);
ylabel(text_wpp);

subplot(2,2,4);
plot(q,qp,'r');
hold on
plot(q_rampe,qp_rampe,'k--');
%title('PTP-Spline 3. Ordnung, Gelenkbeschleunigung')
grid on;
xlabel(text_w);
ylabel(text_wp);

     


